@@ -3,7 +3,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2017 Slaven Rezic. All rights reserved.
+# Copyright (C) 2017,2018 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -14,8 +14,8 @@
 package Doit::File;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = '0.021';
+use warnings;
+our $VERSION = '0.022';
 
 use Doit::Log;
 use Doit::Util qw(copy_stat new_scope_cleanup);
